<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
    xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:marc="http://www.loc.gov/MARC21/slim"
	xmlns:dc="http://purl.org/dc/elements/1.1/"
	xmlns:dcterms="http://purl.org/dc/terms/"
	xmlns:edm="http://www.europeana.eu/schemas/edm/"
	xmlns:ore="http://www.openarchives.org/ore/terms/"
	xmlns:owl="http://www.w3.org/2002/07/owl#"
	xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#"
	xmlns:foaf="http://xmlns.com/foaf/0.1/"
	xmlns:skos="http://www.w3.org/2004/02/skos/core#"
	xmlns:rdaGr2="http://rdvocab.info/ElementsGr2/"
	xmlns:wgs84_pos="http://www.w3.org/2003/01/geo/wgs84_pos#"
	xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance"
    exclude-result-prefixes="marc">

<xsl:import href="../bib/registro_dc.xsl" />

<xsl:import href="../comun/proc_bib_variable.xsl" />
<xsl:import href="../comun/proc_campos.xsl" />
<xsl:import href="../comun/proc_plantilla.xsl" />

<xsl:import href="../comun/campos_bib.xsl" />
<xsl:import href="../comun/campos_hol.xsl" />

<xsl:import href="../comun/util_enlaces.xsl" />
<xsl:import href="../comun/marc_html.xsl" />
<xsl:import href="../comun/marc_util.xsl" />
<xsl:import href="../comun/i18n_control.xsl" />
<xsl:import href="../comun/i18n.xsl" />
<xsl:import href="../comun/util.xsl" />
<xsl:output method="xml" indent="yes" omit-xml-declaration="no" encoding="UTF-8"/>

<xsl:param name="peticionOAI" />


<xsl:variable name="EDM" select="true()" />
<xsl:variable name="DC_CUALIFICADO" select="true()" />

<xsl:variable name="nodo_plantilla" select="document('../datos_plantillas/dc_plantilla.xml')/*" />



<!-- Se saca la url sin idioma -->
<xsl:variable name="URL_BASE">
    <xsl:variable name="ultimo_trozo_idioma">
        <xsl:text>/</xsl:text>
        <xsl:value-of select="substring-after(substring($WEB_ROOT,string-length($WEB_ROOT)-4,string-length($WEB_ROOT)),'/')"/>
    </xsl:variable>
    <xsl:choose>
        <xsl:when test="string-length($ultimo_trozo_idioma)>0">
            <xsl:call-template name="replace">
                <xsl:with-param name="texto" select="$WEB_ROOT" />
                <xsl:with-param name="cadena1" select="$ultimo_trozo_idioma" />
                <xsl:with-param name="cadena2" select="'/'" />
            </xsl:call-template>        
        </xsl:when>
        <xsl:otherwise>
            <xsl:value-of select="$WEB_ROOT"/>
        </xsl:otherwise>
    </xsl:choose>
</xsl:variable>

<xsl:template match="/">
    <xsl:choose>
        <xsl:when test="$peticionOAI=true()">
            <root>
                <xsl:apply-templates select="*/marc:record" />
            </root>
        </xsl:when>
        <xsl:otherwise>
            <rdf:RDF xsi:schemaLocation="http://www.w3.org/1999/02/22-rdf-syntax-ns# http://www.europeana.eu/schemas/edm/EDM.xsd">
                <xsl:apply-templates select="*/marc:record" />
            </rdf:RDF>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>


<xsl:template name="registro_bib">
    <xsl:param name="holdings" />

    <!-- Si es OAI, se aade por cada registro su RDF -->
    <xsl:choose>
        <xsl:when test="$peticionOAI=true()">
            <rdf:RDF xsi:schemaLocation="http://www.w3.org/1999/02/22-rdf-syntax-ns# http://www.europeana.eu/schemas/edm/EDM.xsd">
                <xsl:call-template name="registro_bib_edm">
                    <xsl:with-param name="holdings" select="$holdings" />
                </xsl:call-template>
            </rdf:RDF>
        </xsl:when>
        <xsl:otherwise>
            <xsl:call-template name="registro_bib_edm">
                <xsl:with-param name="holdings" select="$holdings" />
            </xsl:call-template>
        </xsl:otherwise>
    </xsl:choose>
</xsl:template>


<xsl:template name="registro_bib_edm">
    <xsl:param name="holdings" />

    <xsl:variable name="raiz_url">
        <xsl:value-of select="$WEB_ROOT" />
        <xsl:if test="string-length($WEB_ROOT)=0">
            <xsl:value-of select="$web" />
            <xsl:if test="string-length($web)=0">
                <xsl:text>..</xsl:text>
            </xsl:if>
        </xsl:if>
    </xsl:variable>
    <xsl:variable name="raiz_url_i18n">
        <xsl:value-of select="$WEB_ROOT_I18N" />
        <xsl:if test="string-length($WEB_ROOT_I18N)=0">
            <xsl:value-of select="$web" />
            <xsl:if test="string-length($web)=0">
                <xsl:text>..</xsl:text>
            </xsl:if>
        </xsl:if>
    </xsl:variable>
    
    <!-- Se saca el id de la imagen unica para el nodo object -->        
    <xsl:variable name="idImagenUnica">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre" select="'idImagenIndividual'" />
        </xsl:call-template>
    </xsl:variable>
    <!-- Se saca el id de la imagen favorita para el nodo object -->        
    <xsl:variable name="idImagenFavorita">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre" select="'imagenFavorita'" />
        </xsl:call-template>
    </xsl:variable>
    <!-- Se saca el tipo de la imagen favorita para el nodo object -->        
    <xsl:variable name="tipoImagenFavorita">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre" select="'tipoImagenFavorita'" />
        </xsl:call-template>
    </xsl:variable>
    <!-- Se saca el tipo de la imagen nica para el nodo object -->        
    <xsl:variable name="tipoImagenUnica">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre" select="'tipoImagenIndividual'" />
        </xsl:call-template>
    </xsl:variable>
    
    <!-- Ahora elegimos a ver qu imagen y qut tipo se pone, si la favorita o la nica. -->
    <xsl:variable name="idImagen">
        <xsl:choose>
            <xsl:when test="string-length($idImagenUnica)>0">
                <xsl:value-of select="$idImagenUnica"/>
            </xsl:when>
            <xsl:when test="string-length($idImagenFavorita)>0">
                <xsl:value-of select="$idImagenFavorita"/>
            </xsl:when>
        </xsl:choose>
    </xsl:variable>
    <xsl:variable name="tipoImagen">
        <xsl:choose>
            <xsl:when test="string-length($tipoImagenUnica)>0">
                <xsl:value-of select="$tipoImagenUnica"/>
            </xsl:when>
            <xsl:when test="string-length($tipoImagenFavorita)>0">
                <xsl:value-of select="$tipoImagenFavorita"/>
            </xsl:when>
        </xsl:choose>
    </xsl:variable>        
    
    <!-- El id del registro -->
    <xsl:variable name="id">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre" select="'idRegistro'" />
        </xsl:call-template>
    </xsl:variable>
    
    <!-- Se saca la url sin idioma -->
    <xsl:variable name="URL_BASE">
        <xsl:variable name="ultimo_trozo_idioma">
            <xsl:text>/</xsl:text>
            <xsl:value-of select="substring-after(substring($WEB_ROOT,string-length($WEB_ROOT)-4,string-length($WEB_ROOT)),'/')"/>
        </xsl:variable>
        <xsl:choose>
            <xsl:when test="string-length($ultimo_trozo_idioma)>0">
                <xsl:call-template name="replace">
                    <xsl:with-param name="texto" select="$WEB_ROOT" />
                    <xsl:with-param name="cadena1" select="$ultimo_trozo_idioma" />
                    <xsl:with-param name="cadena2" select="'/'" />
                </xsl:call-template>        
            </xsl:when>
            <xsl:otherwise>
                <xsl:value-of select="$WEB_ROOT"/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:variable>
    
    <xsl:variable name="url_ficha">
        <xsl:if test="string-length($id)">
            <xsl:value-of select="$raiz_url"/>
            <xsl:text>/consulta/registro.cmd?id=</xsl:text>
            <xsl:value-of select="$id"/>
        </xsl:if>
    </xsl:variable>


    <!-- The Europeana material type of the resource. All digital objects in Europeana have to be classified as one of the four 
    Europeana material types: TEXT, IMAGE, SOUND or VIDEO. This element is used to create Type facet based on the Europeana material types. 
    A default thumbnail is used in the short or full record display when a thumbnail is not available (see  <europeana:object>) -->
    <xsl:variable name='formats' select="(. | $holdings)/marc:datafield[@tag='856']/marc:subfield[@code='q']" />
    <xsl:variable name="leader" select="marc:leader"/>
    <xsl:variable name="leader6" select="substring($leader,7,1)"/>
    <xsl:variable name="leader7" select="substring($leader,8,1)"/>
    <xsl:variable name="tipo_europeana">
        <xsl:call-template name="get_tipo_europeana_ldr">
            <xsl:with-param name="leader6" select="$leader6" />
            <xsl:with-param name="leader7" select="$leader7" />
            <xsl:with-param name="formatos" select="$formats" />
        </xsl:call-template>    
    </xsl:variable>
    
    <xsl:variable name="url_aggregation_about">
        <xsl:value-of select="$URL_BASE"/>
        <xsl:text>bib/</xsl:text>
        <xsl:value-of select="marc:controlfield[@tag='001']"/>
        <xsl:text>#aggregation</xsl:text>
    </xsl:variable>
    
    <xsl:variable name="url_aggregates_resource">
        <xsl:value-of select="$URL_BASE"/>
        <xsl:text>bib/</xsl:text>
        <xsl:value-of select="marc:controlfield[@tag='001']"/>
    </xsl:variable>
    
    <!-- El id del numero anterior -->
    <xsl:variable name="publicacionControlNumeroAnterior">
        <xsl:call-template name="variable">
            <xsl:with-param name="nombre" select="'publicacionControlNumeroAnterior'" />
        </xsl:call-template>
    </xsl:variable>
    <xsl:variable name="url_anterior_numero">
        <xsl:if test="string-length(normalize-space($publicacionControlNumeroAnterior))>0">    
            <xsl:value-of select="$URL_BASE"/>
            <xsl:text>bib/</xsl:text>
            <xsl:value-of select="$publicacionControlNumeroAnterior"/>
        </xsl:if>
    </xsl:variable>

	<ore:Aggregation rdf:about="{$url_aggregation_about}">
        <edm:aggregatedCHO rdf:resource="{$url_aggregates_resource}" />
        
        <!-- edm:dataProvider -->
        <xsl:choose>
            <xsl:when test="string-length(normalize-space($provider))>0 and starts-with(normalize-space($provider),'http')">
                <edm:dataProvider rdf:resource="{$provider}" />            
            </xsl:when>
            <xsl:when test="string-length(normalize-space($provider))>0">
                <edm:dataProvider><xsl:value-of select="$provider"/></edm:dataProvider>            
            </xsl:when>
            <xsl:otherwise>
                <edm:dataProvider><xsl:text>(unknown)</xsl:text></edm:dataProvider>    
            </xsl:otherwise>
        </xsl:choose>
        
        <!-- edm:isShownAt, edm:isShownBy -->
        <xsl:choose>
            <xsl:when test="string-length($idImagenUnica)>0">
                <xsl:variable name="urlIsShownBy">
                    <xsl:value-of select="$raiz_url_i18n"/>
                    <xsl:text>/catalogo_imagenes/imagen_id.cmd?idImagen=</xsl:text>
                    <xsl:value-of select="$idImagenUnica" />
                </xsl:variable>
                <xsl:if test="string-length($url_ficha)>0">
                    <edm:isShownAt rdf:resource="{$url_ficha}"/>
                </xsl:if>            
                <edm:isShownBy rdf:resource="{$urlIsShownBy}"/>
            </xsl:when>
            <xsl:when test="count((. | $holdings)/marc:datafield[@tag='856'])=1 and count((. | $holdings)/marc:datafield[@tag='856']/marc:subfield[@code='w'])>0">
                <xsl:variable name="urlIsShownAt">
                    <xsl:value-of select="$raiz_url"/>
                    <xsl:text>/catalogo_imagenes/grupo.cmd?path=</xsl:text>
                    <xsl:value-of select="(. | $holdings)/marc:datafield[@tag='856']/marc:subfield[@code='w'][1]" />
                </xsl:variable>
                <edm:isShownAt rdf:resource="{$urlIsShownAt}"/>
            </xsl:when>
            <xsl:otherwise>
                <xsl:if test="string-length($url_ficha)>0">
                    <edm:isShownAt rdf:resource="{$url_ficha}"/>
                </xsl:if>
            </xsl:otherwise>
        </xsl:choose>
        
        <!-- edm:object: Se pone enlace a la imagen grande tanto si es pdf como imagen -->
        <xsl:if test="string-length($idImagen)>0">
            <xsl:choose>
                <xsl:when test="$tipoImagen='application/pdf' or $tipoImagen='image/tiff' or $tipoImagen='image/jpeg'
                    or $tipoImagen='image' or $tipoImagen='image/gif'">
                    <!-- Si es un pdf, se apunta a la miniatura (posiblemente pregenerada)-->
                    <xsl:variable name="urlObject">
                        <xsl:value-of select="$raiz_url_i18n"/>
                        <xsl:text>/catalogo_imagenes/imagen_id.cmd?idImagen=</xsl:text>
                        <xsl:value-of select="$idImagen" />
                    </xsl:variable>
                    <edm:object rdf:resource="{$urlObject}"/>
                </xsl:when>
            </xsl:choose>
        </xsl:if>
        
        <!-- edm:provider -->        
        <xsl:choose>
            <xsl:when test="string-length(normalize-space($provider))>0 and starts-with(normalize-space($provider),'http')">
                <edm:provider rdf:resource="{$provider}" />            
            </xsl:when>
            <xsl:when test="string-length(normalize-space($provider))>0">
                <edm:provider><xsl:value-of select="$provider"/></edm:provider>            
            </xsl:when>
            <xsl:otherwise>
                <edm:provider><xsl:text>(unknown)</xsl:text></edm:provider>            
            </xsl:otherwise>
        </xsl:choose>        
                
        <!-- edm:rights -->        
        <!-- Si es europeana, se ponen los rights, que son variables que deben de empezar en "urlDerechos_" -->
        <xsl:for-each select="marc:datafield[@tag='variable' and starts-with(./marc:subfield[@code='n'],'textoUrlDerechos_') and 
                string-length(normalize-space(substring-after(marc:subfield[@code='v'],'__[]__')))>0]">
            <xsl:if test="position()=1">
                <edm:rights rdf:resource="{normalize-space(substring-after(marc:subfield[@code='v'],'__[]__'))}"/>
            </xsl:if>
        </xsl:for-each>
        <!-- El de por defecto -->
        <xsl:if test="count(marc:datafield[@tag='variable' and starts-with(./marc:subfield[@code='n'],'textoUrlDerechos_') and 
            string-length(normalize-space(substring-after(marc:subfield[@code='v'],'__[]__')))>0])=0">
            <edm:rights rdf:resource="http://www.europeana.eu/rights/rr-f/"/>
        </xsl:if>

        <!-- El formato, de momento no en la primera versin de EDM. Ms adelante tendr que ir aun WebResource especfico -->
        <!-- 
        <xsl:for-each select="$formats">
            <xsl:variable name="positionCurrent" select="position()" />
            <xsl:if test="not($formats[string(.) = string(current()) and (position() &lt; $positionCurrent)])">
                <dc:format>
                   <xsl:value-of select="."/>
                </dc:format>
            </xsl:if>
        </xsl:for-each>
        -->
    </ore:Aggregation>
    
	<edm:ProvidedCHO rdf:about="{$url_aggregates_resource}">
        <xsl:call-template name="registro_bib_dc">
    		<xsl:with-param name="nodo_plantilla" select="$nodo_plantilla" />
            <xsl:with-param name="holdings" select="$holdings" />
            <xsl:with-param name="europeana" select="true()" />
            <xsl:with-param name="linked_data" select="true()" />
    	</xsl:call-template>
        
        <edm:type><xsl:value-of select="$tipo_europeana"/></edm:type>
        
        <!-- El enlace al anterior nmero -->
        <xsl:if test="string-length(normalize-space($url_anterior_numero))>0">
            <edm:isNextInSequence rdf:resource="{$url_anterior_numero}"/>
        </xsl:if>
    </edm:ProvidedCHO>
</xsl:template>


<xsl:template name="procesar_grupo">
	<xsl:param name="tipo" />
	<xsl:param name="valor" />
	<xsl:param name="params" />

	<xsl:call-template name="procesar_grupo_dc">
		<xsl:with-param name="tipo" select="$tipo" />
		<xsl:with-param name="valor" select="$valor" />
		<xsl:with-param name="params" select="$params" />
	</xsl:call-template>
</xsl:template>


<xsl:template name="separador_grupo">
	<xsl:param name="tipo" />

	<xsl:call-template name="separador_grupo_dc">
		<xsl:with-param name="tipo" select="$tipo" />
	</xsl:call-template>
</xsl:template>
	
	
<xsl:template name="valor_grupo">
	<xsl:param name="tipo" />
	<xsl:param name="valor" />
	<xsl:param name="posicion_grupo" />
	<xsl:param name="num_valores_grupo" />
	<xsl:param name="nodo_registro" />
	<xsl:param name="nodo_campo" />

	<xsl:call-template name="valor_grupo_dc">
		<xsl:with-param name="tipo" select="$tipo" />
		<xsl:with-param name="valor" select="$valor" />
		<xsl:with-param name="posicion_grupo" select="$posicion_grupo" />
		<xsl:with-param name="num_valores_grupo" select="$num_valores_grupo" />		
		<xsl:with-param name="nodo_registro" select="$nodo_registro" />		
		<xsl:with-param name="nodo_campo" select="$nodo_campo" />						
	</xsl:call-template>
</xsl:template>

</xsl:stylesheet>
